% CTA_demo1.m
% CTA_demo1.m demonstrates how to obtain Wavelet Multi-scale Descriptor (WMD) 
% from a single brain surface. 

clear;
dir = 'sample/';

% sample subject
subject = 'subject';

% load data
h = 'left';
[surf, sphere, f] = CTA_load_surf(dir, subject, h);
figure;figure_surf(surf, f);

% adjacency matrix and graph Laplacian
A = triangulation2adjacency(surf.faces, surf.vertices);
[D, L] = CTA_spectralgraph(A); 
    
% smoothing    
m = 10; K = 10; alph = 2; tol=1e-3; J=20; d = 5;
f_smooth = CTA_smoothing(f, L, J, d, m, K, alph, tol);   
figure;figure_surf(surf, f_smooth);

% WMD parameters
m = 50; K = 40; alph = 1; J=3; designtype = 'abspline3'; 
lmax = 20.5;
arange = [0 lmax];

[g,t]=sgwt_filter_design_param(lmax,J,'designtype',designtype,'lpfactor',K,'alph',alph);
sgwt_view_design(g,t,arange)

c = cell(numel(g),1);
for k=1:numel(g)
    c{k}=sgwt_cheby_coeff(g{k},m,m+1,arange);
end
    
% computing WMD from cortical thickness    
WMD = sgwt_cheby_op(f,L,c,arange);    

figure;
set(gcf, 'Position', [100 100 1800, 400])
for i=1:J+1
    subplot(1,J+1,i);figure_surf(surf, WMD{i});
end



