% CTA_demo2.m
% CTA_demo2.m demonstrates a standard group analysis process on 2 different
% groups of brain subjects.

clear;
close all;

load demo2_surf.mat;    % load a sample brain surface and atrophy regions

n1 = 20;    % number of subjects in group1
n2 = 20;    % number of subjects in group2

N = length(surf.vertices);
%% Ground truth
p_truth1 = tr1;
p_truth2 = tr2;
p_truth = [tr1;tr2];

f_truth = zeros(N,1);
f_truth(p_truth1) = 1;
f_truth(p_truth2) = 2;

figure;figure_surf(surf, f_truth);  % plot the ground truth
title('ground truth');

%% Generating synthetic cortical thickness and atrophy
for i=1:n1
    f1{i} = normrnd(2,0.1,[N,1]);
    f1{i}(p_truth1) = f1{i}(p_truth1) - normrnd(0.2,0.01,[length(p_truth1),1]);
    f1{i}(p_truth2) = f1{i}(p_truth2) - normrnd(0.4,0.02,[length(p_truth2),1]);    
    f1{i} = f1{i} + normrnd(0,1,[N,1]);
end

for i=1:n2
    f2{i} = normrnd(2,0.1,[N,1]);
    f2{i} = f2{i} + normrnd(0,1,[N,1]);
end

%% smoothing parameter setting
m = 10;
K = 20;
%alph = 1;
alph = 1;
%designtype = 'abspline3';
J = 5;
tol = 1e-3;

%% WMD parameter setting
m2 = 10;
K2 = 60;
%alph = 1;
alph2 = 0.3;
designtype = 'abspline3'; % wavelet type
J2 = 5; % number of scales

lmax = 18.5;
arange = [0 lmax];

[g,t]=sgwt_filter_design_param(lmax,J,'designtype',designtype,'lpfactor',K2,'alph',alph2);

c = cell(numel(g),1);
for k=1:numel(g)
    c{k}=sgwt_cheby_coeff(g{k},m,m+1,arange);
end

%% Smoothing & WMD
A = triangulation2adjacency(surf.faces, surf.vertices);
[D, L] = CTA_spectralgraph(A); 

for i=1:n1   
    % smoothing    
    fs1{i} = CTA_heat_smoothing(f1{i}, L, m, K, alph, tol);   
    
    % WMD    
    WMD1{i} = sgwt_cheby_op(f1{i},L,c,arange);        
end

for i=1:n2   
    % smoothing    
    fs2{i} = CTA_heat_smoothing(f2{i}, L, m, K, alph, tol);   
    
    % WMD    
    WMD2{i} = sgwt_cheby_op(f2{i},L,c,arange);        
end

% t-test on the raw data and the result after multiple comparison
% correction
temp1 = cell2mat(f1);
temp2 = cell2mat(f2);

[h p_raw] = ttest2(temp1', temp2');

q = 0.05;   % FDR
[p_sort, idx, max_k, fdr, thr] = FDR(p_raw, q);

p2 = p_raw;
p2(p2>thr) = 1; % set all p-values above threshold to 1
figure;figure_surf(surf, -log10(p2));

% t-test on the smoothed data and the result after multiple comparison
% correction
temp1 = cell2mat(fs1);
temp2 = cell2mat(fs2);
[h p_smth] = ttest2(temp1', temp2');
[p_sort, idx, max_k, fdr, thr] = FDR(p_smth, q);

p2_smth = p_smth;
p2_smth(p2_smth>thr) = 1;
figure;figure_surf(surf, -log10(p2_smth));

% Hoteling's T2 test on WMD and the result after multiple comparison
% correction
clear temp1 temp2;
for i=1:n1
    temp1(:,:,i) = reshape(cell2mat(WMD1{i}), [], J2+1);
    temp2(:,:,i) = reshape(cell2mat(WMD2{i}), [], J2+1);
end

d = 1:J2-1
[h p_wmd] = hotelT2(temp1(:,d,:), temp2(:,d,:)); 
[p_sort, idx, max_k, fdr, thr] = FDR(p_wmd, q);

p2 = p_wmd;
p2(p2>thr) = 1;
figure;figure_surf(surf, -log10(p2));

