function [f_smooth W] = CTA_heat_smoothing(f, L, m, K, alph, tol)

% CTA_heat_smoothing smoothes a function defined 
% in non-Euclidean space (i.e., Graph) using heat-kernel
% 
% Input: 
%   f: function defined on each vertex
%   L: graph Laplacian
%   m: order of Chebychev approximation
%   K, alph: kernel defining parameter
%   tol: tolerance for Conjugate Gradients in inverse transform
%
% Output: 
%   f_smooth: smoothed function
%   W: transform coefficients
%
% Coded by Won Hwa Kim, 2013
% Dept. of Computer Sciences, University of Wisconsin

J=0;
Nscales = J+1;
lmax = sgwt_rough_lmax(L);
arange = [0 lmax];

designtype = 'heat_kernel';
[g,t]=sgwt_filter_design_param(lmax,J,'designtype',designtype,'lpfactor',K,'alph',alph);

% figure;
% sgwt_view_design(g,t,arange);

c = cell(numel(g),1);
for k=1:numel(g)
    c{k}=sgwt_cheby_coeff(g{k},m,m+1,arange);
end

W=sgwt_cheby_op(f,L,c,arange);

W_re = cell(Nscales,1);
for i=1:Nscales
    W_re{i}=zeros(size(W{i}));
end

W_re{1} = W{1}; 

f_smooth = sgwt_inverse(W_re,L,c,arange, 'tol', tol);
