function [f_smooth W] = CTA_smoothing(f, L, J, d, m, K, alph, tol)

% function CTA_smoothing smoothes a function defined 
% in non-Euclidean space (i.e., Graph) using SGWT, up to dth scale.
% 
% Input: 
%   f: given function
%   L: graph Laplacian
%   J, m, K: SGWT parameters
%   alpha: level of smoothing
%
% Output: 
%   f_smooth: smoothed function
%   W: wavelet coefficients
%
% Coded by Won Hwa Kim, 2013
% Dept. of Computer Sciences, University of Wisconsin

Nscales = J+1;
lmax = sgwt_rough_lmax(L);
arange = [0 lmax];

designtype = 'abspline3';
[g,t]=sgwt_filter_design_param(lmax,J,'designtype',designtype,'lpfactor',K, 'alph', alph);

c = cell(numel(g),1);
for k=1:numel(g)
    c{k}=sgwt_cheby_coeff(g{k},m,m+1,arange);
end

W=sgwt_cheby_op(f,L,c,arange);

W_re = cell(Nscales,1);
for i=1:Nscales
    W_re{i}=zeros(size(W{i}));
end

for s = 1:d
    W_re{s} = W{s}; 
end

f_smooth = sgwt_inverse(W_re,L,c,arange, 'tol', tol);
