function [template, index] = CTA_template(surf, sphere, alpha, FV)

% function CTA_template creates a smoothed brain surface from a given
% surface and the sphere for registration using SGWT.
%
% Input: 
%   surf: brain surface with vertices and faces
%   sphere: brain sphere from Freesurfer
%   alpha: level of smoothing
%   FV: registration sphere
%
% Output: 
%   template: smoothed brain surface with vertices and faces
%   index: vertex correspondence between sphere and FV
%
% Coded by Won Hwa Kim, 2013
% Dept. of Computer Sciences, University of Wisconsin

A = triangulation2adjacency(surf.faces, surf.vertices);
[D, L] = CTA_spectralgraph(A); 

m = 40;
K = 40;
J = 0; 
tol = 10e-3;

v(:,1) = CTA_smoothing(surf.vertices(:,1), L, J, 1, m, K, alpha, tol);   
v(:,2) = CTA_smoothing(surf.vertices(:,2), L, J, 1, m, K, alpha, tol);   
v(:,3) = CTA_smoothing(surf.vertices(:,3), L, J, 1, m, K, alpha, tol);   

template.vertices = v;
template.faces = surf.faces;
index = [];

if nargin == 4    
    [theta, varphi] = EULERangles(sphere);
    [theta_FV, varphi_FV] = EULERangles(FV);

    index = zeros(length(theta),1);
    for n=1:length(theta)
        d = sqrt((theta(n) - theta_FV).^2 + (varphi(n) - varphi_FV).^2);
        [val, index(n)] = min(d);
        %fprintf('...%d...\n',n);
    end    
end
